@@ -6,4 +6,6 @@ authorization = AuthorizationV1(
     username='YOUR SERVICE USERNAME',
     password='YOUR SERVICE PASSWORD')
 
-print(json.dumps(authorization.get_token(url=SpeechToTextV1.default_url), indent=2))
+
+print(json.dumps(authorization.get_token(url=SpeechToTextV1.default_url),
+                 indent=2))
